#
# spec file for package libArcus
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 3
Name:           libArcus
%define sversion        4.13
Version:        4.13.1
Release:        bp156.5.7
Summary:        3D printer control software
License:        LGPL-3.0-only
Group:          Development/Libraries/C and C++
URL:            https://github.com/Ultimaker/%name
Source:         https://github.com/Ultimaker/libArcus/archive/%{sversion}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE - use Qt5 sip import name, taken from Fedora
Patch0:         libArcus-3.5.1-PyQt5.sip.patch
# PATCH-FIX-UPSTREAM
Patch1:         0001-Use-single-parameter-SetTotalBytesLimit-fix-protobuf.patch
BuildRequires:  cmake >= 3.6
BuildRequires:  gcc-c++
BuildRequires:  protobuf-devel >= 3.0.0
BuildRequires:  python3-devel
BuildRequires:  python3-packaging
BuildRequires:  python3-qt5-sip
BuildRequires:  python3-sip4-devel

%description
Communication library between internal components for Ultimaker software

%package -n %name%{sover}
Summary:        3D printer control software
# The forked libArcus-lulzbot uses the same SONAME ...
Group:          System/Libraries
Provides:       libArcus-Ultimaker

%description -n %name%{sover}
Communication library between internal components for Ultimaker software

%package devel
Summary:        Header files for libArcus
Group:          Development/Libraries/C and C++
Requires:       libArcus%{sover} = %{version}
Requires:       protobuf-devel >= 3.0.0
Requires:       python3-sip4-devel < 5

%description devel
The %{name}-devel package includes the header files, libraries and development
tools necessary for compiling and linking programs which use %{name}.

%package -n python3-Arcus
Summary:        Python bindings for libArcus
Group:          Development/Languages/Python
Requires:       libArcus-Ultimaker
Requires:       python3-qt5-sip

%description -n python3-Arcus
Python bindings for the Arcus communication library.

%prep
%autosetup -n %{name}-%{sversion} -p1
# Do not override C++17 default with C++11
sed -i -e '/COMPILE_FLAGS.*c++11/ d' examples/CMakeLists.txt

%build
%cmake

%cmake_build

%install
%cmake_install
# Create a minimal dist-info (PEP 241/314)
cat > %{buildroot}%{python3_sitearch}/Arcus-%{version}.egg-info <<HERE_EOF
Metadata-Version: 1.1
Name: Arcus
Version: %{version}
Summary: Python bindings for libArcus
Author-email: info@ultimaker.com
License: LGPL-3.0-only
Classifier: License :: OSI Approved :: GNU Lesser General Public License v3 (LGPLv3)
HERE_EOF

%post   -n %name%{sover} -p /sbin/ldconfig

%postun -n %name%{sover} -p /sbin/ldconfig

%files devel
%doc TODO.md
%{_includedir}/Arcus
%{_libdir}/cmake/Arcus
%{_libdir}/libArcus.so

%files -n %name%{sover}
%license LICENSE
%doc README.md
%{_libdir}/libArcus.so.*

%files -n python3-Arcus
%license LICENSE
%{python3_sitearch}/Arcus.so
%{python3_sitearch}/Arcus-*.egg-info

%changelog
* Thu Jul  6 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Remove explicit --std=c++11 in example compile flags, keep c++17
  default required by absl.
* Sat Jul  1 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Depend on python3-sip4-devel explicitly, as it no longer
  provides python3-sip-devel.
* Tue Jun 21 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Add egg-info, to enable automatic creation of versioned python
  dependency provides.
* Sat Feb 26 2022 Max Lin <mlin@suse.com>
- Use BuildRequires python3-qt5-sip for Leap 15.4
* Sun Feb  6 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 4.13.1
  Release notes:
  * https://github.com/Ultimaker/Cura/releases/tag/4.13.1
* Sun Jan 30 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build with protobuf >= 3.18, add
  0001-Use-single-parameter-SetTotalBytesLimit-fix-protobuf.patch
* Fri Jan 14 2022 Paolo Stivanin <info@paolostivanin.com>
- update to 4.13.0
  Release notes:
  * https://github.com/Ultimaker/Cura/releases/tag/4.13.0
- Delete 0001-Fix-build-with-Python-3.8-and-no-undefined-linker-flags.patch
- Refresh libArcus-3.5.1-PyQt5.sip.patch
* Mon Apr 26 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 4.9.0
  Release notes:
  * https://github.com/Ultimaker/Cura/releases/tag/4.9
* Sun Nov 22 2020 Benjamin Greiner <code@bnavigator.de>
- Require the sip module (under PyQt5.sip namespace as per patch)
* Sat Nov 21 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Depend on python3-sip < 5, as libArcus build is incompatible with
  SIP 5 and upstream currently has no intention to update, see
  gh#Ultimaker/libSavitar#26.
- Move the python bindings to a separate package which can be used
  as a dependency elsewhere.
* Tue Nov 10 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 4.8.0
  * no code changes, just some build system churn.
- Fix build error with Python 3.8, add
  0001-Fix-build-with-Python-3.8-and-no-undefined-linker-flags.patch
* Tue Sep 15 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 4.7.1
  * Do not link to libpython with Python >= 3.8
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 4.6.2
  * no code changes
* Sun Jun  7 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to version 4.6.1
  * no code changes
- Fix Arcus python import error with current PyQt5, add
  libArcus-3.5.1-PyQt5.sip.patch
* Thu Jan  2 2020 Adrian Schröter <adrian@suse.de>
- update to version 4.4.1
  * no code changes
* Fri Nov 22 2019 Adrian Schröter <adrian@suse.de>
- update to version 4.4.0
  obsoletes
  0001-Install-the-Python-extension-module-to-Python-sitear.patch
  0002-Fix-Python3_SITEARCH-for-old-cmake.patch
* Sun Oct 13 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Make sure the package actually builds, add
  0001-Install-the-Python-extension-module-to-Python-sitear.patch
  0002-Fix-Python3_SITEARCH-for-old-cmake.patch
* Fri Sep 27 2019 Adrian Schröter <adrian@suse.de>
- update to version 4.3.0
  * no code changes
* Thu Sep  5 2019 Adrian Schröter <adrian@suse.de>
- fix build for factory
* Mon Aug 12 2019 Adrian Schröter <adrian@suse.de>
- udpate to version 4.2.0
  * just build env changes
* Thu Jun 13 2019 Adrian Schröter <adrian@suse.de>
- update to version 4.1.0
  * https://ultimaker.com/en/products/ultimaker-cura-software/release-notes
* Fri Jan 18 2019 Adrian Schröter <adrian@suse.de>
- obsolete libArcus3-lulzbot
  (patched lulzbot edition to work with upstream libArcus)
* Fri Nov 16 2018 Adrian Schröter <adrian@suse.de>
- version update to 3.6.0
  * version change only
* Wed Oct 17 2018 Adrian Schröter <adrian@suse.de>
- version update to 3.5.1
  * version change only
* Fri Jul 27 2018 jengelh@inai.de
- Rename %%soname to %%sover to better reflect its use.
- Fix RPM groups.
* Mon Jul 16 2018 adrian@suse.de
- update to version 3.4.1
  * version update only
* Mon Jul  9 2018 adrian@suse.de
- update to version 3.3.0
  * no release notes
* Sat Jan 27 2018 stefan.bruens@rwth-aachen.de
- adapt directories, the binary python module is installed in the
  correct location now, i.e. %%{python_sitearch}
* Thu Jan 25 2018 adrian@suse.de
- update to 3.1.0
* Fri Dec  8 2017 stefan.bruens@rwth-aachen.de
- Fix License, Cura 3.0 and libraries are LGPL-3.0 now
* Thu Dec  7 2017 stefan.bruens@rwth-aachen.de
- Revert majority of previos changes, which not only updated the
  version, but reverted the previous cleanup
* Fri Nov  3 2017 adrian@suse.de
- update to version 3.0.3
* Tue Sep 12 2017 stefan.bruens@rwth-aachen.de
- Cleanup spec file
* Mon Sep  4 2017 adrian@suse.de
- update to version 2.7.0
* Mon Jun 26 2017 adrian@suse.de
- switch to stable version 2.6.0
* Mon Jun 20 2016 adrian@suse.de
- initial package of git master version
  (stable ones need old development snapshots for protobuf)
